@@ -24,6 +24,12 @@ app = Fermata(
         'name': 'specs/api.yml',
         'tpl': 'openapi: 3.0.3\n'
     },
+    {
+        'name': 'requirements.txt',
+        'tpl': '''fermata
+pyyaml
+'''
+    },
 ]
 
 
